==> zio-aws-ssoadmin_3-5.19.31.1-sources.jar: zio/aws/ssoadmin/model/AttachedManagedPolicy.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.ssoadmin.model.primitives.{ManagedPolicyArn, Name}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AttachedManagedPolicy(
    name: Optional[Name] = Optional.Absent,
    arn: Optional[ManagedPolicyArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy = {
    import AttachedManagedPolicy.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
      .builder()
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .optionallyWith(
        arn.map(value => ManagedPolicyArn.unwrap(value): java.lang.String)
      )(_.arn)
      .build()
  }
  def asReadOnly: zio.aws.ssoadmin.model.AttachedManagedPolicy.ReadOnly =
    zio.aws.ssoadmin.model.AttachedManagedPolicy.wrap(buildAwsValue())
}
object AttachedManagedPolicy {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssoadmin.model.AttachedManagedPolicy =
      zio.aws.ssoadmin.model.AttachedManagedPolicy(
        name.map(value => value),
        arn.map(value => value)
      )
    def name: Optional[Name]
    def arn: Optional[ManagedPolicyArn]
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
    def getArn: ZIO[Any, AwsError, ManagedPolicyArn] =
      AwsError.unwrapOptionField("arn", arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
  ) extends zio.aws.ssoadmin.model.AttachedManagedPolicy.ReadOnly {
    override val name: Optional[Name] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.ssoadmin.model.primitives.Name(value))
    override val arn: Optional[ManagedPolicyArn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.ssoadmin.model.primitives.ManagedPolicyArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
  ): zio.aws.ssoadmin.model.AttachedManagedPolicy.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ssoadmin_3-7.21.15.10-sources.jar: zio/aws/ssoadmin/model/AttachedManagedPolicy.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.ssoadmin.model.primitives.{Name, ManagedPolicyArn}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AttachedManagedPolicy(
    arn: Optional[ManagedPolicyArn] = Optional.Absent,
    name: Optional[Name] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy = {
    import AttachedManagedPolicy.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
      .builder()
      .optionallyWith(
        arn.map(value => ManagedPolicyArn.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .build()
  }
  def asReadOnly: zio.aws.ssoadmin.model.AttachedManagedPolicy.ReadOnly =
    zio.aws.ssoadmin.model.AttachedManagedPolicy.wrap(buildAwsValue())
}
object AttachedManagedPolicy {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssoadmin.model.AttachedManagedPolicy =
      zio.aws.ssoadmin.model.AttachedManagedPolicy(
        arn.map(value => value),
        name.map(value => value)
      )
    def arn: Optional[ManagedPolicyArn]
    def name: Optional[Name]
    def getArn: ZIO[Any, AwsError, ManagedPolicyArn] =
      AwsError.unwrapOptionField("arn", arn)
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
  ) extends zio.aws.ssoadmin.model.AttachedManagedPolicy.ReadOnly {
    override val arn: Optional[ManagedPolicyArn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.ssoadmin.model.primitives.ManagedPolicyArn(value))
    override val name: Optional[Name] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.ssoadmin.model.primitives.Name(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.AttachedManagedPolicy
  ): zio.aws.ssoadmin.model.AttachedManagedPolicy.ReadOnly = new Wrapper(impl)
}
